Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
Settings *config.Settings
Snapd snapdapi.SnapdClient
}
Service implements the identity service use cases
func NewService ¶
func NewService(settings *config.Settings, snapd snapdapi.SnapdClient) *Service
NewService creates a new identity service connection
func (*Service) CheckEnrollment ¶
func (srv *Service) CheckEnrollment() (*domain.Enrollment, error)
CheckEnrollment verifies that the device is enrolled with the identity service
type UseCase ¶
type UseCase interface {
CheckEnrollment() (*domain.Enrollment, error)
}
UseCase is the interface for the identity service use cases
Click to show internal directories.
Click to hide internal directories.